Third Party Software
====================

The octree-creation-app repository and source distributions bundle several libraries that are
compatibly licensed.  We list these here.

.. list-table::
  :widths: 30 30 60
  :header-rows: 1

  * - Name
    - License
    - Description
  * - `discretize <https://simpeg.xyz/>`_
    - MIT
    - Discretization tools for finite volume and inverse problems
  * - `geoh5py <https://github.com/MiraGeoscience/geoh5py>`_
    - LGPL-3.0-or-later
    - Python API for geoh5, an open file format for geoscientific data
  * - `geoapps-utils <https://github.com/MiraGeoscience/geoapps-utils>`_
    - MIT
    - Utilities for geoscientific applications.
  * - `numpy <https://github.com/numpy/numpy>`_
    - BSD-3-Clause
    - Fundamental package for array computing in Python
  * - `scipy <https://github.com/scipy/scipy>`_
    - BSD-3-Clause
    - Fundamental algorithms for scientific computing in Python
